@@ -13,16 +13,16 @@ import torchmetrics
 from torchmetrics import Accuracy
 from torch.utils.data import DataLoader
 
-from PIL import Image, ImageEnhance
+from sklearn import metrics
 from sklearn.metrics import precision_recall_fscore_support as f_score
 
 from transformers import Trainer
-from transformers import default_data_collator
 from transformers.training_args import TrainingArguments
 from transformers.feature_extraction_utils import FeatureExtractionMixin
 
 from tqdm import tqdm
 from tabulate import tabulate
+from PIL import Image, ImageEnhance
 
 from hugsvision.dataio.ImageClassificationCollator import ImageClassificationCollator
 
@@ -163,15 +163,12 @@ class VisionClassifierTrainer:
     # Get the hypothesis and predictions
     all_target, all_preds = self.evaluate()
 
-    print(self.ids2labels.keys())
-    print(self.labels2ids.keys())
-
-    from sklearn import metrics
     table = metrics.classification_report(
       all_target,
       all_preds,
-      labels = [int(a) for a in list(self.labels2ids.keys())],
-      target_names = list(self.ids2labels.keys()),
+      labels = [int(a) for a in list(self.ids2labels.keys())],
+      target_names = list(self.labels2ids.keys()),
+      zero_division = 0,
     )
     print(table)
 
@@ -206,7 +203,7 @@ class VisionClassifierTrainer:
         # Get hypothesis
         all_target.append(label)
 
-    return all_preds, all_target
+    return all_target, all_preds
 
   """
   🧪 Test on a single image
